Welcome to IoC's documentation!
===============================

Contents:

.. toctree::
   :maxdepth: 2

   install
   references
   extra

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

